@@ -1,4 +1,4 @@
-
+context("simple tests")
 
 test_that("tidyfeed returns an error when it should", {
  expect_error(tidyfeed("hello"))
@@ -8,10 +8,7 @@ test_that("tidyfeed returns an error when it should", {
 
 test_that("tidyfeed returns a data_frame", {
   data("feeds")
-
-  for(i in 1:nrow(feeds)){
-    feed <- feeds$feeds[[i]]
-    expect_is(tidyfeed(feed), "tbl_df", info = paste(i, feed))
-  }
+  rss <- sample(feeds$feeds, 1)
+  expect_is(tidyfeed(rss), "tbl_df")
 })
 
